XPylonIterable<T> extension

Extension on Iterable to transform collections into lists of Pylon widgets for building dynamic UIs with multiple Pylon instances.

on

Methods

withPylons(PylonBuilder builder) List<Widget>

Available on Iterable<T>, provided by the XPylonIterable extension

Maps each item in this iterable to a Pylon widget using the provided builder, returning a list suitable for use in widget trees.