XPylonIterable<T> extension
Extension on Iterable to transform collections into lists of Pylon widgets for building dynamic UIs with multiple Pylon instances.
- on
-
- Iterable<
T>
- Iterable<
Methods
-
withPylons(
PylonBuilder builder) → List< Widget> -
Available on Iterable<
Maps each item in this iterable to a Pylon widget using the providedT> , provided by the XPylonIterable extensionbuilder, returning a list suitable for use in widget trees.